# [pynex](https://github.com/Pixelsuft/pynex/)
PyGame based GUI Library
## Screenshots
[![Screenshot1](https://user-images.githubusercontent.com/68371847/162572356-c4fe6ab7-d1b7-40e4-b563-53872776b5bb.png)](https://github.com/Pixelsuft/pynex)
## Install
On Windows:
```sh
python -m pip install pynex
```
On Linux:
```sh
python3 -m pip install pynex
```
## Links
[Readme](https://github.com/Pixelsuft/pynex/blob/main/README.MD) <br />
[Example](https://github.com/Pixelsuft/pynex/blob/main/main.py) <br />
[Issue tracker](https://github.com/Pixelsuft/pynex/issues)
